pyproject_api: API to interact with the python pyproject.toml based projects
============================================================================

Description
-----------

API to interact with the python pyproject.toml based projects

License
-------

Upstream Contact
----------------

https://pypi.org/project/pyproject-api/

